package com.inspect.taskftp.mapper;

import com.inspect.taskftp.domain.PatrolTaskFtp;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface PatrolTaskFtpMapper {
    PatrolTaskFtp selectPatrolTaskFtpByLineId(Long lineId);

    List<PatrolTaskFtp> selectPatrolTaskFtpList(PatrolTaskFtp ftp);

    int insertPatrolTaskFtp(PatrolTaskFtp ftp);

    int updatePatrolTaskFtp(PatrolTaskFtp ftp);

    int deletePatrolTaskFtpByLineId(Long lineId);

    int deletePatrolTaskFtpByLineIds(Long[] lineIds);
}
